--AH:ScriptId=3a066690-772e-4a87-b133-690241d3428c;2841
CREATE TABLE [RetentionPolicies]
(
	[RetentionPolicy_Id] INT NOT NULL IDENTITY(1, 1),
	[RetentionPolicy_Name] NVARCHAR(50) NULL,
	[PurgeType_Code] CHAR(1) NOT NULL,

	[PurgeIn_Application_Id] INT NULL,
	[PurgeIn_ApplicationGroup_Id] INT NULL,
	[PurgeIn_OnlyDeployedReleases_Indicator] YNINDICATOR NOT NULL,
	[PurgeIn_OnlyRejectedBuilds_Indicator] YNINDICATOR NOT NULL,
	[PurgeIn_Workflow_Id] INT NULL,
	[PurgeIn_Environment_Id] INT NULL,
	[PurgeIn_BuildStep_Indicator] YNINDICATOR NOT NULL,

	[PurgeWhen_Count] INT NULL,
	[PurgeWhen_Size] INT NULL,
	[PurgeWhen_ReleaseDeployed_Indicator] YNINDICATOR NULL,
	[PurgeWhen_Days_Count] INT NULL,
	[PurgeWhen_TimeOfDay_Minutes] INT NULL,
	[PurgeWhen_Now_Indicator] YNINDICATOR NOT NULL,

	[CreatedBy_User_Name] USERNAME NOT NULL,
	[CreatedOn_Date] DATETIME NOT NULL,

	[ModifiedBy_User_Name] USERNAME NULL,
	[ModifiedOn_Date] DATETIME NULL,

	CONSTRAINT [PK__RetentionPolicies]
		PRIMARY KEY ([RetentionPolicy_Id]),

	CONSTRAINT [CK__RetentionPolicies__RetentionPolicy_Name]
		CHECK (RTRIM(LTRIM([RetentionPolicy_Name])) <> ''),

	CONSTRAINT [CK__RetentionPolicies__PurgeType_Code]
		CHECK ([PurgeType_Code] IN ('R', 'B', 'L', 'A')),

	CONSTRAINT [FK__RetentionPolicies__Applications]
		FOREIGN KEY ([PurgeIn_Application_Id])
		REFERENCES [Applications] ([Application_Id]),

	CONSTRAINT [FK__RetentionPolicies__ApplicationGroups]
		FOREIGN KEY ([PurgeIn_ApplicationGroup_Id])
		REFERENCES [ApplicationGroups] ([ApplicationGroup_Id]),

	CONSTRAINT [FK__RetentionPolicies__Workflows]
		FOREIGN KEY ([PurgeIn_Workflow_Id])
		REFERENCES [Workflows] ([Workflow_Id]),

	CONSTRAINT [FK__RetentionPolicies__Environments]
		FOREIGN KEY ([PurgeIn_Environment_Id])
		REFERENCES [Environments] ([Environment_Id]),

	CONSTRAINT [CK__RetentionPolicies__PurgeWhen_Count]
		CHECK ([PurgeWhen_Count] IS NULL OR [PurgeWhen_Count] >= 0),

	CONSTRAINT [CK__RetentionPolicies__PurgeWhen_Size]
		CHECK ([PurgeWhen_Size] IS NULL OR [PurgeWhen_Size] >= 0),

	CONSTRAINT [CK__RetentionPolicies__PurgeWhen_Days_Count]
		CHECK ([PurgeWhen_Days_Count] IS NULL OR [PurgeWhen_Days_Count] >= 0),

	CONSTRAINT [CK__RetentionPolicies__PurgeWhen_TimeOfDay_Minutes]
		CHECK ([PurgeWhen_TimeOfDay_Minutes] IS NULL OR ([PurgeWhen_TimeOfDay_Minutes] >= 0 AND [PurgeWhen_TimeOfDay_Minutes] < 1440)),

	CONSTRAINT [CK__RetentionPolicies__ApplicationScope_Valid]
		CHECK ([PurgeIn_Application_Id] IS NULL OR [PurgeIn_ApplicationGroup_Id] IS NULL),

	CONSTRAINT [CK__RetentionPolicies__SizeValidForScope]
		CHECK ([PurgeWhen_Size] IS NULL OR [PurgeType_Code] IN ('L', 'A')),

	CONSTRAINT [CK__RetentionPolicies__CountValidForScope]
		CHECK ([PurgeWhen_Count] IS NULL OR [PurgeType_Code] IN ('R', 'B')),

	CONSTRAINT [CK__RetentionPolicies__BuildStatusValidForScope]
		CHECK ([PurgeIn_OnlyRejectedBuilds_Indicator] = 'N' OR [PurgeType_Code] IN ('B', 'L', 'A')),

	CONSTRAINT [CK__RetentionPolicies__EnvironmentValidForScope]
		CHECK (([PurgeIn_Environment_Id] IS NULL AND [PurgeIn_BuildStep_Indicator] = 'N') OR [PurgeType_Code] = 'L'),

	CONSTRAINT [CK__RetentionPolicies__EnvironmentScope_Valid]
		CHECK ([PurgeIn_Environment_Id] IS NULL OR [PurgeIn_BuildStep_Indicator] = 'N')
)

CREATE TABLE [RetentionPoliciesPurgeHistory]
(
	[RetentionPoliciesPurgeHistoryEntry_Id] INT IDENTITY(1, 1) NOT NULL,
	[Original_RetentionPolicy_Id] INT NOT NULL,
	[Original_RetentionPolicy_Name] NVARCHAR(50) NOT NULL,
	[Start_Date] DATETIME NOT NULL,
	[End_Date] DATETIME NULL,
	[LogText_Bytes] VARBINARY(MAX) NULL,

	CONSTRAINT [PK__RetentionPoliciesPurgeHistory]
		PRIMARY KEY ([RetentionPoliciesPurgeHistoryEntry_Id])
)

CREATE NONCLUSTERED INDEX [IX__RetentionPoliciesPurgeHistory__Date]
	ON [RetentionPoliciesPurgeHistory] ([Start_Date] DESC)
	INCLUDE ([Original_RetentionPolicy_Id])