EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_InitiateBuildExecution',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Execution_Id',
    /* Description_Text        */ 'Initiates a new build execution.'
GO

IF OBJECT_ID('[Builds_InitiateBuildExecution]') IS NOT NULL DROP PROCEDURE [Builds_InitiateBuildExecution]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_InitiateBuildExecution]
(
	@Promotion_Id INT,
	@Plan_Name VARCHAR(255),
	@Start_Date DATETIME,
	@Environment_Id INT,
	@DependentUpon_Execution_Id INT = NULL,
    @PipelineStageTarget_Index INT = NULL,
	@Execution_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	SET @Start_Date = COALESCE(@Start_Date, GETUTCDATE())

	DECLARE @Application_Id INT
	SELECT @Application_Id = R.[Application_Id]
	  FROM [BuildPromotions] BP
	       INNER JOIN [Builds] B
		           ON B.[Build_Id] = BP.[Promotion_Id]
		   INNER JOIN [Releases] R
		           ON R.[Release_Id] = B.[Release_Id]

	INSERT INTO [Executions]
	(
		[Start_Date],
		[ExecutionStatus_Code],
		[ExecutionRunState_Code],
		[ExecutionMode_Code],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[DependentUpon_Execution_Id]
	)
	VALUES
	(
		@Start_Date,
		'S',
		'P',
		'B',
		dbo.Session_GetUserName(),
		GETUTCDATE(),
		@DependentUpon_Execution_Id
	)

	SET @Execution_Id = SCOPE_IDENTITY()

	INSERT INTO [BuildExecutions]
	(
		[Execution_Id],
		[Promotion_Id],
		[Plan_Name],
		[Environment_Id],
        [PipelineStageTarget_Index]
	)
	VALUES
	(
		@Execution_Id,
		@Promotion_Id,
		@Plan_Name,
		@Environment_Id,
        @PipelineStageTarget_Index
	)

	EXEC [Events_RaiseEvent] 'EXEINI', @Application_Id, @Execution_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH
END
GO

GRANT EXECUTE ON [Builds_InitiateBuildExecution] TO [BuildMasterUser_Role]
