EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ExtensionConfiguration_SaveConfiguration',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ExtensionConfiguration_Id',
    /* Description_Text        */ 'Creates an extension configurer in the system, or updates an existing one'
GO

IF OBJECT_ID('[ExtensionConfiguration_SaveConfiguration]') IS NOT NULL DROP PROCEDURE [ExtensionConfiguration_SaveConfiguration]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ExtensionConfiguration_SaveConfiguration] 
(
	@ExtensionConfiguration_Id INT OUT,

	@QualifiedType_Name VARCHAR(500),
	@Profile_Name VARCHAR(50),

	@Extension_Configuration VARCHAR(MAX),
	@Default_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION
		
		IF (@ExtensionConfiguration_Id IS NULL)
		BEGIN

			INSERT INTO [ExtensionConfigurations]
					   ([QualifiedType_Name]
					   ,[Profile_Name]
					   ,[Extension_Configuration]
					   ,[CreatedBy_User_Name]
					   ,[CreatedOn_Date]
					   ,[ModifiedBy_User_Name]
					   ,[ModifiedOn_Date]
					   ,[Default_Indicator])
				 VALUES
					   (@QualifiedType_Name
					   ,@Profile_Name
					   ,@Extension_Configuration
					   ,dbo.Session_GetUserName()
					   ,GETUTCDATE()
					   ,dbo.Session_GetUserName()
					   ,GETUTCDATE()
					   ,@Default_Indicator)
			SET @ExtensionConfiguration_Id = SCOPE_IDENTITY()

		END ELSE BEGIN

			UPDATE [ExtensionConfigurations]
			   SET [QualifiedType_Name] = @QualifiedType_Name
			      ,[Profile_Name] = @Profile_Name
			      ,[Extension_Configuration] = @Extension_Configuration
			      ,[ModifiedBy_User_Name] = dbo.Session_GetUserName()
			      ,[ModifiedOn_Date] = GETUTCDATE()
			      ,[Default_Indicator] = @Default_Indicator
			 WHERE [ExtensionConfiguration_Id] = @ExtensionConfiguration_Id

		END

        IF (@Default_Indicator = 'Y')
        BEGIN 
                
        UPDATE [ExtensionConfigurations]
            SET [Default_Indicator] = 'N'
            WHERE [QualifiedType_Name] = @QualifiedType_Name
            AND [ExtensionConfiguration_Id] <> @ExtensionConfiguration_Id

        END

		/* Raise Extension Configured event */
		EXEC [Events_RaiseEvent] 'EXTCFG', NULL, @QualifiedType_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ExtensionConfiguration_SaveConfiguration] TO [BuildMasterUser_Role]
GO