EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'LegacyExecutions_GetExecutionLog',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'BuildExecutions_Extended,BuildExecution_DeploymentPlanActionGroups,BuildExecution_ActionGroupActions,BuildExecution_ActionGroupActionLogEntries,BuildExecution_ActionGroupActionVariableValues',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the details for a specified build execution, and plan or action if specified.'
GO

IF OBJECT_ID('[LegacyExecutions_GetExecutionLog]') IS NOT NULL DROP PROCEDURE [LegacyExecutions_GetExecutionLog]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [LegacyExecutions_GetExecutionLog]
(
	@Execution_Id INT = NULL,
    @BuildExecution_DeploymentPlan_Id INT = NULL,
    @Original_DeploymentPlanActionGroup_Sequence INT = NULL,
	@BuildExecution_ActionGroupAction_Id INT = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	IF @Execution_Id IS NOT NULL
	BEGIN

		-- Executions_Extended
		SELECT *
		  FROM [BuildExecutions_Extended]
		 WHERE [Execution_Id] = @Execution_Id

		-- BuildExecution_DeploymentPlanActionGroups
		SELECT BEDPAG.*
		  FROM [BuildExecution_DeploymentPlanActionGroups] BEDPAG
		       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
		               ON BEDP.[BuildExecution_DeploymentPlan_Id] = BEDPAG.[BuildExecution_DeploymentPlan_Id]
		 WHERE BEDP.[Execution_Id] = @Execution_Id

		-- BuildExecution_ActionGroupActions
		SELECT BEAGA.*
		  FROM [BuildExecution_ActionGroupActions] BEAGA
  		       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
		               ON BEDP.[BuildExecution_DeploymentPlan_Id] = BEAGA.[BuildExecution_DeploymentPlan_Id]
		 WHERE BEDP.[Execution_Id] = @Execution_Id

		-- BuildExecution_ActionGroupActionLogEntries
		SELECT BEAGALE.*
		  FROM [BuildExecution_ActionGroupActionLogEntries] BEAGALE
		       INNER JOIN [BuildExecution_ActionGroupActions] BEAGA
			           ON BEAGA.[BuildExecution_ActionGroupAction_Id] = BEAGALE.[BuildExecution_ActionGroupAction_Id]
  		       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
		               ON BEDP.[BuildExecution_DeploymentPlan_Id] = BEAGA.[BuildExecution_DeploymentPlan_Id]
		 WHERE BEDP.[Execution_Id] = @Execution_Id

		-- BuildExecution_ActionGroupActionVariableValues
		SELECT BEAGAVV.*
		  FROM [BuildExecution_ActionGroupActionVariableValues] BEAGAVV
			   INNER JOIN [BuildExecution_ActionGroupActions] BEAGA
		               ON BEAGA.[BuildExecution_ActionGroupAction_Id] = BEAGAVV.[BuildExecution_ActionGroupAction_Id]
  		       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
		               ON BEDP.[BuildExecution_DeploymentPlan_Id] = BEAGA.[BuildExecution_DeploymentPlan_Id]
		 WHERE BEDP.[Execution_Id] = @Execution_Id

	END
	ELSE IF @BuildExecution_DeploymentPlan_Id IS NOT NULL
	BEGIN

		-- Executions_Extended
		SELECT BEX.*
		  FROM [BuildExecution_DeploymentPlans] BEDP
		       INNER JOIN [BuildExecutions_Extended] BEX
		               ON BEX.[Execution_Id] = BEDP.[Execution_Id]
		 WHERE BEDP.[BuildExecution_DeploymentPlan_Id] = @BuildExecution_DeploymentPlan_Id

		-- BuildExecution_DeploymentPlanActionGroups
		SELECT *
		  FROM [BuildExecution_DeploymentPlanActionGroups]
		 WHERE [BuildExecution_DeploymentPlan_Id] = @BuildExecution_DeploymentPlan_Id
		   AND (@Original_DeploymentPlanActionGroup_Sequence IS NULL OR [Original_DeploymentPlanActionGroup_Sequence] = @Original_DeploymentPlanActionGroup_Sequence)

		-- BuildExecution_ActionGroupActions
		SELECT *
		  FROM [BuildExecution_ActionGroupActions]
		 WHERE [BuildExecution_DeploymentPlan_Id] = @BuildExecution_DeploymentPlan_Id
	       AND (@Original_DeploymentPlanActionGroup_Sequence IS NULL OR [Original_DeploymentPlanActionGroup_Sequence] = @Original_DeploymentPlanActionGroup_Sequence)

		-- BuildExecution_ActionGroupActionLogEntries
		SELECT BEAGALE.*
		  FROM [BuildExecution_ActionGroupActionLogEntries] BEAGALE
		       INNER JOIN [BuildExecution_ActionGroupActions] BEAGA
			           ON BEAGA.[BuildExecution_ActionGroupAction_Id] = BEAGALE.[BuildExecution_ActionGroupAction_Id]
		 WHERE BEAGA.[BuildExecution_DeploymentPlan_Id] = @BuildExecution_DeploymentPlan_Id
		   AND (@Original_DeploymentPlanActionGroup_Sequence IS NULL OR [Original_DeploymentPlanActionGroup_Sequence] = @Original_DeploymentPlanActionGroup_Sequence)

		-- BuildExecution_ActionGroupActionVariableValues
		SELECT BEAGAVV.*
		  FROM [BuildExecution_ActionGroupActionVariableValues] BEAGAVV
			   INNER JOIN [BuildExecution_ActionGroupActions] BEAGA
		               ON BEAGA.[BuildExecution_ActionGroupAction_Id] = BEAGAVV.[BuildExecution_ActionGroupAction_Id]
		 WHERE BEAGA.[BuildExecution_DeploymentPlan_Id] = @BuildExecution_DeploymentPlan_Id
		   AND (@Original_DeploymentPlanActionGroup_Sequence IS NULL OR [Original_DeploymentPlanActionGroup_Sequence] = @Original_DeploymentPlanActionGroup_Sequence)

	END
	ELSE IF @BuildExecution_ActionGroupAction_Id IS NOT NULL
	BEGIN

		-- Executions_Extended
		SELECT BEX.*
		  FROM [BuildExecution_ActionGroupActions] BEAGA
		       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
		               ON BEDP.[BuildExecution_DeploymentPlan_Id] = BEAGA.[BuildExecution_DeploymentPlan_Id]
		       INNER JOIN [BuildExecutions_Extended] BEX
		               ON BEX.[Execution_Id] = BEDP.[Execution_Id]
		 WHERE BEAGA.[BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id

		-- BuildExecution_DeploymentPlanActionGroups
		SELECT BEDPAG.*
		  FROM [BuildExecution_ActionGroupActions] BEAGA
		       INNER JOIN [BuildExecution_DeploymentPlanActionGroups] BEDPAG
		               ON BEDPAG.[BuildExecution_DeploymentPlan_Id] = BEAGA.[BuildExecution_DeploymentPlan_Id]
		              AND BEDPAG.[Original_DeploymentPlanActionGroup_Sequence] = BEAGA.[Original_DeploymentPlanActionGroup_Sequence]
		 WHERE BEAGA.[BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id

		-- BuildExecution_ActionGroupActions
		SELECT *
		  FROM [BuildExecution_ActionGroupActions]
		 WHERE [BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id

		-- BuildExecution_ActionGroupActionLogEntries
		SELECT *
		  FROM [BuildExecution_ActionGroupActionLogEntries]
		 WHERE [BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id

		-- BuildExecution_ActionGroupActionVariableValues
		SELECT *
		  FROM [BuildExecution_ActionGroupActionVariableValues]
		 WHERE [BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id

	END

END
GO

GRANT EXECUTE ON [LegacyExecutions_GetExecutionLog] TO [BuildMasterUser_Role]
