EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_UpdateDeploymentPlanActionGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
     /* Description_Text        */ 'Updates the specified deployment plan action group.'
GO

IF OBJECT_ID('[Plans_UpdateDeploymentPlanActionGroup]') IS NOT NULL DROP PROCEDURE [Plans_UpdateDeploymentPlanActionGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_UpdateDeploymentPlanActionGroup]
(
	@DeploymentPlanActionGroup_Id INT,
	@Active_Indicator YNINDICATOR,
	@ActionGroup_Name VARCHAR(50),
	@ActionGroup_Description VARCHAR(MAX),
	@Predicate_Configuration XML,
	@Server_Id INT,
	@Server_Variable_Name VARCHAR(50),
	@Deployable_Name VARCHAR(50),
	@Deployable_Application_Id INT,
	@Iterate_Servers_Indicator YNINDICATOR,
	@Iterate_Deployables_Indicator YNINDICATOR,
	@Parallel_Indicator YNINDICATOR,
	@OnSuccess_DeploymentPlanActionGroup_Id INT,
	@OnFailure_DeploymentPlanActionGroup_Id INT,
	@OnFailure_Continue_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION
	
	DECLARE @DeploymentPlan_Id INT
	SET @DeploymentPlan_Id = (SELECT [DeploymentPlan_Id]
	                            FROM [DeploymentPlanActionGroups]
	                           WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id)

    UPDATE [DeploymentPlanActionGroups]
       SET [Active_Indicator] = @Active_Indicator
          ,[ActionGroup_Name] = NULLIF(@ActionGroup_Name, '')
          ,[ActionGroup_Description] = NULLIF(@ActionGroup_Description, '')
          ,[Predicate_Configuration] = @Predicate_Configuration
          ,[Server_Id] = @Server_Id
          ,[Server_Variable_Name] = NULLIF(@Server_Variable_Name, '')
          ,[Deployable_Name] = NULLIF(@Deployable_Name, '')
          ,[Deployable_Application_Id] = @Deployable_Application_Id
          ,[ModifiedBy_User_Name] = dbo.Session_GetUserName()
          ,[ModifiedOn_Date] = GETUTCDATE()
          ,[Iterate_Servers_Indicator] = @Iterate_Servers_Indicator
          ,[Iterate_Deployables_Indicator] = @Iterate_Deployables_Indicator
          ,[Parallel_Indicator] = @Parallel_Indicator
          ,[OnSuccess_DeploymentPlanActionGroup_Id] = @OnSuccess_DeploymentPlanActionGroup_Id
          ,[OnFailure_DeploymentPlanActionGroup_Id] = @OnFailure_DeploymentPlanActionGroup_Id
          ,[OnFailure_Continue_Indicator] = @OnFailure_Continue_Indicator
     WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

 	-- disable reexecution for anything that used the modified plan
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
	                            FROM [BuildExecution_DeploymentPlans] BEDP
	                           WHERE BEDP.[Original_DeploymentPlan_Id] = @DeploymentPlan_Id)
	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_UpdateDeploymentPlanActionGroup] TO [BuildMasterUser_Role]
