EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Variables_CreateOrUpdateVariableDeclaration',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'VariableDeclaration_Id',
    /* Description_Text        */ 'Creates a new variable declaration or updates an existing one.'
GO


IF OBJECT_ID('[Variables_CreateOrUpdateVariableDeclaration]') IS NOT NULL DROP PROCEDURE [Variables_CreateOrUpdateVariableDeclaration]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Variables_CreateOrUpdateVariableDeclaration]
(
	@VariableDeclaration_Id INT OUT,
	@Variable_Name VARCHAR(50),
	@Scope_Code CHAR(1),
	@Scoped_Application_Id INT,
	@Scoped_PipelineStage_Name VARCHAR(50),
	@Scoped_Environment_Id INT,
	@Required_Indicator YNINDICATOR,
	@Variable_Configuration XML,
	@DefaultValue_Text VARCHAR(MAX),
	@Sensitive_Indicator YNINDICATOR
)
AS
BEGIN

	SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION
	
	IF @VariableDeclaration_Id IS NULL
	BEGIN
		INSERT INTO [VariableDeclarations]
		(
			[Variable_Name],
			[Scope_Code],
			[Scoped_Application_Id],
			[Scoped_PipelineStage_Name],
			[Scoped_Environment_Id],
			[Required_Indicator],
			[Variable_Configuration],
			[DefaultValue_Text],
			[CreatedBy_User_Name],
			[CreatedOn_Date],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date],
			[Sensitive_Indicator]
		)
		VALUES
		(
			@Variable_Name,
			@Scope_Code,
			@Scoped_Application_Id,
			@Scoped_PipelineStage_Name,
			@Scoped_Environment_Id,
			@Required_Indicator,
			@Variable_Configuration,
			@DefaultValue_Text,
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			@Sensitive_Indicator
		)

		SET @VariableDeclaration_Id = SCOPE_IDENTITY()
	END
	ELSE
	BEGIN
		UPDATE [VariableDeclarations]
		   SET [Required_Indicator] = COALESCE(@Required_Indicator, [Required_Indicator]),
			   [Variable_Configuration] = COALESCE(@Variable_Configuration, [Variable_Configuration]),
			   [Scoped_PipelineStage_Name] = @Scoped_PipelineStage_Name,
			   [Scoped_Environment_Id] = @Scoped_Environment_Id,
			   [DefaultValue_Text] = @DefaultValue_Text,
			   [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
			   [ModifiedOn_Date] = GETUTCDATE(),
			   [Sensitive_Indicator] = @Sensitive_Indicator
		 WHERE [VariableDeclaration_Id] = @VariableDeclaration_Id
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Variables_CreateOrUpdateVariableDeclaration] TO [BuildMasterUser_Role]