EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Variables_CreateOrUpdateVariableDefinition',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new variable definition or updates an existing one.'
GO


IF OBJECT_ID('[Variables_CreateOrUpdateVariableDefinition]') IS NOT NULL DROP PROCEDURE [Variables_CreateOrUpdateVariableDefinition]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Variables_CreateOrUpdateVariableDefinition]
(
	@Variable_Name VARCHAR(50),
	@Environment_Id INT,
    @ServerRole_Id INT,
	@Server_Id INT,
	@ApplicationGroup_Id INT,
	@Application_Id INT,
	@Deployable_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER,
	@Promotion_Id INT,
	@Execution_Id INT,
	@Value_Text VARCHAR(MAX),
	@Sensitive_Indicator YNINDICATOR
)
AS
BEGIN

	SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Build_Id INT
	DECLARE @Release_Id INT
	SELECT @Build_Id = [Build_Id]
	  FROM [Builds_Extended]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number
	   AND [Build_Number] = @Build_Number

	IF @Build_Id IS NULL
	BEGIN

		SELECT @Release_Id = [Release_Id]
		  FROM [Releases]
		 WHERE [Application_Id] = @Application_Id
		   AND [Release_Number] = @Release_Number

	END

    DECLARE @Inferred_Scope_Code CHAR(1)
        SET @Inferred_Scope_Code = CASE
            WHEN @ServerRole_Id IS NOT NULL THEN 'L'
            WHEN @Server_Id IS NOT NULL THEN 'V'
            WHEN @ApplicationGroup_Id IS NOT NULL THEN 'G'
            WHEN @Deployable_Id IS NOT NULL THEN 'D'
            WHEN @Environment_Id IS NOT NULL THEN 'E'
			WHEN @Promotion_Id IS NOT NULL THEN 'P'
            WHEN @Execution_Id IS NOT NULL THEN 'X'
            WHEN @Build_Id IS NOT NULL THEN 'B'
			WHEN @Release_Id IS NOT NULL THEN 'R'
            WHEN @Application_Id IS NOT NULL THEN 'A'
            ELSE 'S' END
            
    DECLARE @VariableDeclaration_Id INT
		SET @VariableDeclaration_Id =
              (SELECT [VariableDeclaration_Id] 
                 FROM [VariableDeclarations]
                WHERE [Variable_Name] = @Variable_Name
                  AND [Scope_Code] = @Inferred_Scope_Code
                  AND ([Scope_Code] NOT IN ('R','B','P','X') OR [Scoped_Application_Id] = @Application_Id)
                  AND ([Scope_Code] NOT IN ('P','X') OR [Scoped_Environment_Id] = @Environment_Id))

    DECLARE @Proper_Variable_Name VARCHAR(50)
    DECLARE @Declaration_Sensitive_Indicator YNINDICATOR

    SELECT @Proper_Variable_Name = [Variable_Name],
           @Declaration_Sensitive_Indicator = [Sensitive_Indicator]
      FROM [VariableDeclarations]
     WHERE [VariableDeclaration_Id] = @VariableDeclaration_Id

    SET @Variable_Name = COALESCE(@Proper_Variable_Name, @Variable_Name)
    SET @Sensitive_Indicator = COALESCE(@Declaration_Sensitive_Indicator, @Sensitive_Indicator)

    DECLARE @VariableDefinition_Id INT
        SET @VariableDefinition_Id = (SELECT [VariableDefinition_Id] FROM [VariableDefinitions]
             WHERE [Variable_Name] = @Variable_Name
               AND ([Environment_Id] = @Environment_Id OR ([Environment_Id] IS NULL AND @Environment_Id IS NULL))
               AND ([ServerRole_Id] = @ServerRole_Id OR ([ServerRole_Id] IS NULL AND @ServerRole_Id IS NULL))
               AND ([Server_Id] = @Server_Id OR ([Server_Id] IS NULL AND @Server_Id IS NULL))
               AND ([ApplicationGroup_Id] = @ApplicationGroup_Id OR ([ApplicationGroup_Id] IS NULL AND @ApplicationGroup_Id IS NULL))
               AND ([Deployable_Id] = @Deployable_Id OR ([Deployable_Id] IS NULL AND @Deployable_Id IS NULL))

               AND ([Application_Id] = @Application_Id OR ([Application_Id] IS NULL AND @Application_Id IS NULL) OR (@Build_Id IS NOT NULL) OR (@Release_Id IS NOT NULL))
               AND ([Release_Id] = @Release_Id OR ([Release_Id] IS NULL AND @Release_Id IS NULL) OR (@Build_Id IS NOT NULL))
               AND ([Build_Id] = @Build_Id OR ([Build_Id] IS NULL AND @Build_Id IS NULL))

			   AND ([Promotion_Id] = @Promotion_Id OR ([Promotion_Id] IS NULL AND @Promotion_Id IS NULL))

               AND ([Execution_Id] = @Execution_Id OR ([Execution_Id] IS NULL AND @Execution_Id IS NULL)) )

    IF @VariableDefinition_Id IS NULL
    BEGIN

		INSERT INTO [VariableDefinitions] 
        (
			[Variable_Name],
			[Environment_Id],
            [ServerRole_Id],
			[Server_Id],
			[ApplicationGroup_Id],
			[Application_Id],
			[Deployable_Id], 
			[Release_Id],
			[Build_Id],
			[Execution_Id],
			[Promotion_Id],
			[Value_Text],
			[Sensitive_Indicator]
		)
		VALUES
		(
			@Variable_Name,
			@Environment_Id,
            @ServerRole_Id,
			@Server_Id,
			@ApplicationGroup_Id,
			CASE WHEN @Build_Id IS NULL AND @Release_Id IS NULL THEN @Application_Id ELSE NULL END,
			@Deployable_Id,
			@Release_Id,
			@Build_Id,
			@Execution_Id,
			@Promotion_Id,
			@Value_Text,
			@Sensitive_Indicator
		)

	END
	ELSE
	BEGIN

		UPDATE [VariableDefinitions]
		   SET [Value_Text] = @Value_Text,
		       [Sensitive_Indicator] = @Sensitive_Indicator
		 WHERE [VariableDefinition_Id] = @VariableDefinition_Id

	END


	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Variables_CreateOrUpdateVariableDefinition] TO [BuildMasterUser_Role]